GetPythonPath: Get Python Executable Path

View source: R/21_GetPythonPath.R

GetPythonPathR Documentation

Get Python Executable Path

Description

This function attempts to find the Python executable within a given environment path. It checks different candidate paths based on the operating system.

Usage

GetPythonPath(path)

Arguments

path

Character string specifying the path to the environment where Python might be located.

Value

Character string with the normalized path to the Python executable if found, otherwise NA_character_.


SigBridgeRUtils documentation built on Sept. 29, 2026, 5:09 p.m.