View source: R/24_caller_cli.R
| GetCallerInfo | R Documentation |
Retrieves the name of the function that called the current execution context. If called from the global environment, returns "global".
GetCallerInfo(offset = 2L)
offset |
Integer. The number of stack frames to go back. Defaults to 2 (skipping the GetCallerInfo frame and the Wrapper frame to find the User's function). |
Character string. E.g., "my_function()" or "global".
## Not run:
f <- function() { GetCallerInfo() }
f() # Returns "f()"
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.