View source: R/21_GetPythonPath.R
| GetPythonPath | R Documentation |
This function attempts to find the Python executable within a given environment path. It checks different candidate paths based on the operating system.
GetPythonPath(path)
path |
Character string specifying the path to the environment where Python might be located. |
Character string with the normalized path to the Python executable if found,
otherwise NA_character_.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.