| TimeStamp | R Documentation |
Creates a formatted character string representing the current system time. The format is "YYYY/mm/DD HH:MM:SS" (year/month/day hour:minute:second).
TimeStamp()
Character string with current time in "YYYY/mm/DD HH:MM:SS" format. If system time is unavailable, returns a fixed timestamp.
Other TimeStamp:
AddTimeStamp2cli(),
CreateTimeStampCliEnv()
## Not run:
# Current time as formatted string
TimeStamp()
# Returns something like: "2025/06/15 16:04:00"
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.